#include <avr/io.h>
#include <avr/interrupt.h>
#define F_CPU 16000000
#include <util/delay.h>

#define MAXPOWER_16 0x00CF
#define MAXPOWER_8 0xCF

void USART0_init(unsigned int baud) {
    /* seteaza baud rate */
    UBRR0H = (unsigned char)(baud>>8);
    UBRR0L = (unsigned char)baud;
 
    /* porneste transmi?atorul */
    UCSR0B = (1<<TXEN0);
 
    /* seteaza formatul frame-ului: 8 bi?i de date, 2 bi?i de stop, fara paritate */
    UCSR0C = (1<<USBS0)|(3<<UCSZ00);
}

void timer1_init()
{
	/* Set prescaler to 8 */
	TCCR1B |= (1 << CS11);

	/* Set OCR2A and OCR2B */
	OCR1A = MAXPOWER_16;
	OCR1B = MAXPOWER_16;
	
	/* Set to Fast PWM */
	TCCR1A |= (1 << WGM10) | (1 << WGM12);
	
	/* Set to Non-Inverting mode */
	TCCR1A |= (1 << COM1A1);
	/* Set to Inverting mode */
	TCCR1A |= (1 << COM1B1) | (1 << COM1B0);

	/* Initialize input pins */
	DDRD |= (1 << PD4) | (1 << PD5);
	PORTD &= ~((1 << PD4) | (1 << PD5));
}

void timer2_init()
{
	/* Set prescaler to 8 */
	TCCR2B |= (1 << CS21);

	/* Set OCR2A and OCR2B */
	OCR2A = MAXPOWER_8;
	OCR2B = MAXPOWER_8;
	
	/* Set to Fast PWM */
	TCCR2A |= (1 << WGM20) | (1 << WGM21);
	
	/* Set to Non-Inverting mode */
	TCCR2A |= (1 << COM2A1);
	/* Set to Inverting mode */
	TCCR2A |= (1 << COM2B1) | (1 << COM2B0);

	/* Initialize input pins */
	DDRD |= (1 << PD6) | (1 << PD7);
	PORTD &= ~((1 << PD6) | (1 << PD7));
}

int main(void)
{
	int a = 0;

	timer1_init();
	timer2_init();
	
	while(1)
	{
		
		if(a)
		{
			TCCR2A &= ~((1 << COM2A1) | (1 << COM2A0) | (1 << COM2B1) | (1 << COM2B0));
			TCCR2A |= (1 << COM2A1);
			TCCR2A |= (1 << COM2B1) | (1 << COM2B0);
			_delay_ms(2000);
		}
		else
		{
			TCCR2A &= ~((1 << COM2A1) | (1 << COM2A0) | (1 << COM2B1) | (1 << COM2B0));
			TCCR2A |= (1 << COM2A1) | (1 << COM2A0);
			TCCR2A |= (1 << COM2B1);
			_delay_ms(500);
		}
		
		a ^= 1;
	}
		
	return 0;
}